@@ -1,28 +1,18 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-"""
-@File    :  MultiPlexing.py
-@Time    :  2022/7/12 16:53
-@Author  :  Ayuge
-@Version :  1.0
-@Contact :  ayuge.s@qq.com
-@License :  (c)Copyright 2022-2023
-@Desc    :  用于存放经常使用的方法
-"""
 import copy
 import json
-import re
 import os
-import cv2
 import random
-import pymysql
-import numpy as np
+import re
 from typing import Optional, Union
+
+import cv2
+import numpy as np
+import pymysql
+
 from ayugespidertools.config import logger
 
-
 __all__ = [
-    'ReuseOperation',
+    "ReuseOperation",
 ]
 
 
@@ -32,7 +22,9 @@ class ReuseOperation(object):
     """
 
     @staticmethod
-    def judge_file_style(media_file_or_url: str, media_type: Optional[str] = None, strict: bool = False) -> str:
+    def judge_file_style(
+        media_file_or_url: str, media_type: Optional[str] = None, strict: bool = False
+    ) -> str:
         """
         判断新增图片的格式类型（此方法是为了防止图片地址格式不统一，造成图片格式提取错误）
         Args:
@@ -44,13 +36,23 @@ class ReuseOperation(object):
             1): 文件的格式信息
         """
         if any([media_file_or_url.startswith("http"), strict]):
-            image_style = ['.svg', '.png', '.jpg', '.jpeg', '.bmp', '.wav', '.mp3', '.ogg', '.flv']
+            image_style = [
+                ".svg",
+                ".png",
+                ".jpg",
+                ".jpeg",
+                ".bmp",
+                ".wav",
+                ".mp3",
+                ".ogg",
+                ".flv",
+            ]
             for image_format in image_style:
                 if image_format in media_file_or_url:
                     return image_format[1:]
 
         # 否则就是文件，则返回文件后缀即可
-        return media_file_or_url.split('.')[-1]
+        return media_file_or_url.split(".")[-1]
 
     @staticmethod
     def get_file_name_by_url(file_url: str) -> str:
@@ -137,14 +139,14 @@ class ReuseOperation(object):
         Returns:
             ret: 返回当前权重的账号信息 account_arr 中的一个账号信息
         """
-        total = sum(item['weight'] for item in weight_data)
+        total = sum(item["weight"] for item in weight_data)
         # 在 0 与权重和之间获取一个随机数
         ra = random.uniform(0, total)
         curr_sum = 0
         ret = None
         for data in weight_data:
             # 在遍历中，累加当前权重值
-            curr_sum += data['weight']
+            curr_sum += data["weight"]
             # 当随机数 <= 当前权重和时，返回权重 key
             if ra <= curr_sum:
                 ret = data
@@ -184,9 +186,7 @@ class ReuseOperation(object):
         # 参数先要满足最小限定，然后再取出限定的参数值；否则直接返回 False
         return (
             {k: dict_config[k] for k in key_list}
-            if cls.if_dict_meet_min_limit(
-                dict_config=dict_config, key_list=key_list
-            )
+            if cls.if_dict_meet_min_limit(dict_config=dict_config, key_list=key_list)
             else False
         )
 
@@ -224,18 +224,24 @@ class ReuseOperation(object):
         # 判断 pymysql_dict_config 是否满足最少的 key 值
         judge_pymysql_dict_config = cls.if_dict_meet_min_limit(
             dict_config=pymysql_dict_config,
-            key_list=["host", "port", "user", "password", "charset"]
+            key_list=["host", "port", "user", "password", "charset"],
         )
-        assert judge_pymysql_dict_config, "创建数据库时的 pymysql 连接参数不满足条件，可能多了 database 参数，或者少了某些参数！"
+        assert (
+            judge_pymysql_dict_config
+        ), "创建数据库时的 pymysql 连接参数不满足条件，可能多了 database 参数，或者少了某些参数！"
 
         pymysql_dict_config_tmp = copy.deepcopy(pymysql_dict_config)
         if "database" in pymysql_dict_config_tmp:
             del pymysql_dict_config_tmp["database"]
         conn = pymysql.connect(**pymysql_dict_config_tmp)
         cursor = conn.cursor()
-        cursor.execute(f'''CREATE DATABASE `{pymysql_dict_config["database"]}` character set {pymysql_dict_config["charset"]};''')
+        cursor.execute(
+            f"""CREATE DATABASE `{pymysql_dict_config["database"]}` character set {pymysql_dict_config["charset"]};"""
+        )
         conn.close()
-        logger.info(f'''创建数据库 {pymysql_dict_config["database"]} 成功，其 charset 类型是：{pymysql_dict_config["charset"]}!''')
+        logger.info(
+            f"""创建数据库 {pymysql_dict_config["database"]} 成功，其 charset 类型是：{pymysql_dict_config["charset"]}!"""
+        )
 
     @classmethod
     def dict_keys_to_lower(cls, deal_dict: dict) -> dict:
@@ -247,8 +253,12 @@ class ReuseOperation(object):
         Returns:
             1).处理后的 dict 值
         """
-        str_key_to_lower_dict = {k.lower(): v for k, v in deal_dict.items() if isinstance(k, str)}
-        not_str_key_dict = {k: v for k, v in deal_dict.items() if not isinstance(k, str)}
+        str_key_to_lower_dict = {
+            k.lower(): v for k, v in deal_dict.items() if isinstance(k, str)
+        }
+        not_str_key_dict = {
+            k: v for k, v in deal_dict.items() if not isinstance(k, str)
+        }
         # python 3.9+ 可优化为：str_key_to_lower_dict |= not_str_key_dict
         str_key_to_lower_dict.update(not_str_key_dict)
         return str_key_to_lower_dict
@@ -264,9 +274,13 @@ class ReuseOperation(object):
             1).处理后的 dict 值
         """
         # 找出 str 类型的 key 字段数据，并将其大写
-        str_key_to_upper_dict = {k.upper(): v for k, v in deal_dict.items() if isinstance(k, str)}
+        str_key_to_upper_dict = {
+            k.upper(): v for k, v in deal_dict.items() if isinstance(k, str)
+        }
         # 找出非 str 类型的数据
-        not_str_key_dict = {k: v for k, v in deal_dict.items() if not isinstance(k, str)}
+        not_str_key_dict = {
+            k: v for k, v in deal_dict.items() if not isinstance(k, str)
+        }
         # 将大写处理的字典加上非 str 类型的 key 字段数据
         str_key_to_upper_dict.update(not_str_key_dict)
         return str_key_to_upper_dict
@@ -281,12 +295,11 @@ class ReuseOperation(object):
         Returns:
             consul_conf_dict_min: 满足要求的最少要求的 consul 配置
         """
-        consul_conf_dict = settings.get('CONSUL_CONFIG')
+        consul_conf_dict = settings.get("CONSUL_CONFIG")
         consul_conf_dict_lowered = cls.dict_keys_to_lower(consul_conf_dict)
         # 取最少需要配置的值，consul 一般情况下最少需要 host, port 和 token 共三个值
         consul_conf_dict_min = cls.get_items_by_keys(
-            dict_config=consul_conf_dict_lowered,
-            key_list=["host", "port", "token"]
+            dict_config=consul_conf_dict_lowered, key_list=["host", "port", "token"]
         )
         assert consul_conf_dict_min, f"consul 配置：{consul_conf_dict} 不满足最小参数配置要求！"
         # 添加 key_values 的值，如果没有设置，则默认取全局配置中的 ENV 值
@@ -330,7 +343,10 @@ class ReuseOperation(object):
         """
         # 也可以这样写，但不推荐
         # dict(line.split("=", 1) for line in headers_ck_str.split("; "))
-        return {x.split("=", 1)[0].strip(): x.split("=", 1)[1].strip() for x in headers_ck_str.split(";")}
+        return {
+            x.split("=", 1)[0].strip(): x.split("=", 1)[1].strip()
+            for x in headers_ck_str.split(";")
+        }
 
     @staticmethod
     def get_req_dict_from_scrapy(req_body_data_str: str) -> dict:
@@ -342,7 +358,9 @@ class ReuseOperation(object):
         Returns:
             1). 转化 dict 格式后的 body
         """
-        return {x.split("=", 1)[0]: x.split("=", 1)[1] for x in req_body_data_str.split("&")}
+        return {
+            x.split("=", 1)[0]: x.split("=", 1)[1] for x in req_body_data_str.split("&")
+        }
 
     @staticmethod
     def get_array_dimension(array: list) -> int:
@@ -369,5 +387,15 @@ class ReuseOperation(object):
 
         """1 + max(map(depthCount,x)) if x and isinstance(x,list) else 0"""
         # 先判断是否为数组类型的元素
-        judge_array = isinstance(array, (frozenset, list, set, tuple,))
-        return int(judge_array) and len(array) and 1 + max(map(cls.get_array_depth, array))
+        judge_array = isinstance(
+            array,
+            (
+                frozenset,
+                list,
+                set,
+                tuple,
+            ),
+        )
+        return (
+            int(judge_array) and len(array) and 1 + max(map(cls.get_array_depth, array))
+        )
